@@ -1,23 +1,6 @@
-/*
- * Copyright (C) 2021 Uniontech Technology Co., Ltd.
- *
- * Author:     yeshanshan <yeshanshan@uniontech.com>
- *
- * Maintainer: yeshanshan <yeshanshan@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2021 - 2022 Uniontech Software Technology Co.,Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
 
 #include <QBuffer>
 #include <QDir>
@@ -225,3 +208,53 @@ TEST_F(ut_DConfigRefServer, setDelayReleaseTime) {
     ASSERT_EQ(server->getRefResourceCountOnTheSR(Service1, Resource2), 0);
     ASSERT_EQ(server->getRefResourceCountOnTheSR(Service1, Resource3), 0);
 }
+
+class ut_ConfigSyncRequestCache : public testing::Test
+{
+protected:
+    static void SetUpTestCase() {
+    }
+    static void TearDownTestCase() {
+    }
+    virtual void SetUp() override {
+        cache.reset(new ConfigSyncRequestCache);
+    }
+    virtual void TearDown() override;
+    QScopedPointer<ConfigSyncRequestCache> cache;
+};
+
+void ut_ConfigSyncRequestCache::TearDown() { }
+
+TEST_F(ut_ConfigSyncRequestCache, base) {
+    cache->setDelaySyncTime(1);
+    ASSERT_EQ(cache->delaySyncTime(), 1);
+    cache->setBatchCount(1);
+    ASSERT_EQ(cache->batchCount(), 1);
+
+    QSignalSpy spy(cache.data(), &ConfigSyncRequestCache::syncConfigRequest);
+
+    const QString userKey("user-config");
+    const auto userConfigCacheKey = ConfigSyncRequestCache::userKey(userKey);
+    ASSERT_TRUE(ConfigSyncRequestCache::isUserKey(userConfigCacheKey));
+    ASSERT_EQ(ConfigSyncRequestCache::getUserKey(userConfigCacheKey), userKey);
+
+    const QString globalKey("global-config");
+    const auto globalConfigCacheKey = ConfigSyncRequestCache::globalKey(globalKey);
+    ASSERT_TRUE(ConfigSyncRequestCache::isGlobalKey(globalConfigCacheKey));
+    ASSERT_EQ(ConfigSyncRequestCache::getGlobalKey(globalConfigCacheKey), globalKey);
+
+    cache->pushRequest(userKey);
+    cache->pushRequest(globalKey);
+
+    ASSERT_EQ(cache->requestsCount(), 2);
+
+    spy.wait(cache->delaySyncTime());
+    ASSERT_EQ(spy.count(), 1);
+
+    ASSERT_EQ(cache->requestsCount(), 1);
+
+    spy.wait(cache->delaySyncTime());
+    ASSERT_EQ(spy.count(), 2);
+
+    ASSERT_EQ(cache->requestsCount(), 0);
+}
